@@ -3,9 +3,15 @@
  *
  * encrypt.h -   defs and protos for encrypt.c
  *
- * $Id: encrypt.h,v 1.1 1994/06/08 17:22:08 schemers Exp $
+ * encrypt.h,v 1.2 2003/08/18 19:03:26 eagle Exp
+ *
+ * encrypt.h,v
+ * Revision 1.2  2003/08/18 19:03:26  eagle
+ * Update the arguments for send_encrypted_chunk and receive_encrypted_chunk
+ * to match the header prototypes for Kerberos v5 1.3.x.  This will now
+ * produce warnings for Kerberos v5 1.2.x, but it should end up being
+ * equivalent, and this method is more completely correct.
  *
- * $Log: encrypt.h,v $
  * Revision 1.1  1994/06/08 17:22:08  schemers
  * Initial revision
  *
@@ -22,7 +28,7 @@ send_encrypted_chunk(
          char *in,
          int   in_len,
          int   sock,
-         des_cblock session,
+         des_cblock *session,
          des_key_schedule sched,
          struct sockaddr_in *sender,
          struct sockaddr_in *receiver);
@@ -34,7 +40,7 @@ receive_encrypted_chunk(
          char *out,
          int   out_max,
          int   sock,
-         des_cblock session,
+         des_cblock *session,
          des_key_schedule sched,
          struct sockaddr_in *sender,
          struct sockaddr_in *receiver);
