@@ -1,40 +1,14 @@
-/***************************************************************************
- *
- * kftgt.c -   client program for kftgtd
- *
- * $Id: kftgt.c,v 1.6 2003/03/04 00:59:26 eagle Exp $
- *
- * $Log: kftgt.c,v $
- * Revision 1.6  2003/03/04 00:59:26  eagle
- * Return specific error codes on any failures.
- *
- * Revision 1.5  2001/03/22 19:18:43  bbense
- * Minor tweaks to get rid of warnings.
- *
- * Revision 1.4  1997/11/24 18:33:34  opusl
- * fix usage string
- *
- * Revision 1.3  1997/11/24 18:14:31  opusl
- * allow forwarding to multiple hosts and usernames (MASSIVE reorg)
- *
- * Revision 1.2  1997/10/26 03:49:14  opusl
- * reformat, ANSIfy
- *
- * Revision 1.1  1994/06/08 17:28:04  schemers
- * Initial revision
- *
- *
- *--------------------------------------------------------------------------
- * Copyright (c) 1994,1997 Board of Trustees, Leland Stanford Jr. University
- ***************************************************************************/
-#ifndef lint
-static char _rcs_id[]="$Id: kftgt.c,v 1.6 2003/03/04 00:59:26 eagle Exp $";
-#endif
+/*  kftgt.c,v 1.9 2005/05/20 01:17:28 eagle Exp
+**
+**  Client program for Kerberos v4 ticket forwarding.
+*/
 
 /*
  * INCLUDES
  */
 
+#include "config.h"
+
 #include <unistd.h>
 #include <stdlib.h>
 #include <stdio.h>
@@ -43,7 +17,6 @@ static char _rcs_id[]="$Id: kftgt.c,v 1.6 2003/03/04 00:59:26 eagle Exp $";
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
-#include <krb.h>
 #include <errno.h>
 #include <memory.h>
 #include <string.h>
@@ -51,6 +24,12 @@ static char _rcs_id[]="$Id: kftgt.c,v 1.6 2003/03/04 00:59:26 eagle Exp $";
 #include <signal.h>
 #include <stdarg.h>
 
+#ifdef HAVE_KERBEROSIV_KRB_H
+# include <kerberosIV/krb.h>
+#else
+# include <krb.h>
+#endif
+
 #include "kftgt.h"
 #include "encrypt.h"
 #include "marsh.h"
@@ -102,7 +81,7 @@ timeout(int signo)
 int
 main(int argc, char **argv)
 {
-  enum kftgt_error status;
+  enum kftgt_error status = SUCCESS;
 
   argv = read_options(argc, argv);
   while(*argv) {
@@ -198,19 +177,16 @@ kftgt(char *ruser, char *server)
   struct sockaddr_in saddr, caddr;
   struct servent *se;
   unsigned int addr;
-  size_t slen, clen;
+  size_t clen;
   char *remote_host;
-  char *server_name;
   int status;
   int sock, len;
   KTEXT_ST ticket;
 
-  KRB_INT32 authopts;
   MSG_DAT msg_data;
   CREDENTIALS cred;
   CREDENTIALS tgtcred;
   Key_schedule sched;
-  KRB_UINT32 cksum;
   char buffer[KFTGT_MAX_BUFFER];
   MSG_DAT m_data;
 
@@ -327,7 +303,7 @@ kftgt(char *ruser, char *server)
   }
 
   if (send_encrypted_chunk(buffer, len, sock, 
-			   cred.session, sched, &caddr, &saddr) < 0) {
+			   &cred.session, sched, &caddr, &saddr) < 0) {
     warn("error sending encrypted params");
     close(sock);
     return ERROR_SEND;
@@ -336,7 +312,7 @@ kftgt(char *ruser, char *server)
   /* read encrypted response */
 
   len = receive_encrypted_chunk(&m_data, buffer, sizeof(buffer), sock,
-				cred.session, sched, &saddr, &caddr);
+				&cred.session, sched, &saddr, &caddr);
 
   if (strncmp(m_data.app_data,"ok",2)!=0) {
     warn("%s",m_data.app_data);
@@ -362,14 +338,14 @@ kftgt(char *ruser, char *server)
   }
 
   if (send_encrypted_chunk(buffer, len, sock, 
-			   cred.session, sched, &caddr, &saddr) < 0) {
+			   &cred.session, sched, &caddr, &saddr) < 0) {
     warn("error sending encrypted user name");
     close(sock);
     return ERROR_SEND;
   }
 
   len = receive_encrypted_chunk(&m_data,buffer,sizeof(buffer), sock,
-				cred.session, sched, &saddr, &caddr);
+				&cred.session, sched, &saddr, &caddr);
 
   if (strncmp(m_data.app_data,"ok",2)!=0) {
     warn("%s",m_data.app_data);
